@@ -28,10 +28,16 @@ gpclibCheck <- function (fatal = TRUE)
                           sQuote(paste0("help(", pkgname, ")")), ".")
 
     ## decide if we should run all examples (some take a few seconds)
-    allExamples <- if (interactive()) TRUE else {
-        .withTimings <- Sys.getenv("_R_CHECK_TIMINGS_")
-        withTimings <- !is.na(.withTimings) && nzchar(.withTimings)
-        !withTimings
+    allExamples <- if (interactive()) {
+        TRUE
+    } else { # R CMD check
+        ## only do all examples if a specific environment variable is set
+        ## (to any value different from "")
+        nzchar(Sys.getenv("_R_SURVEILLANCE_ALL_EXAMPLES_"))
+        ## CAVE: testing for _R_CHECK_TIMINGS_ as in surveillance < 1.9-1
+        ## won't necessarily skip long examples for daily checks on CRAN (see
+        ## https://stat.ethz.ch/pipermail/r-devel/2012-September/064812.html
+        ## ). For instance, the daily Windows checks run without timings.
     }
     surveillance.options(allExamples = allExamples)
 }
@@ -66,7 +72,7 @@ formatPval <- function (pv, eps = 1e-4, scientific = FALSE, ...)
 {
     format1 <- function (p)
         format.pval(p, digits = if (p < 10*eps) 1 else 2, eps = eps,
-                    scientific = scientific, ...)
+                    nsmall = 2, scientific = scientific, ...)
     vapply(X = pv, FUN = format1, FUN.VALUE = "", USE.NAMES = TRUE)
 }
 
@@ -92,32 +98,3 @@ hcl.colors <- function (ncolors=100, use.color=TRUE)
     
     return(rev(GYR))
 }
-
-
-
-
-###############################################################
-### backwards-compatibility for old class name "ah4" (<= 1.7-0)
-###############################################################
-
-local({
-    methods17 <- c("print", "summary", "print.summary", "terms", "logLik",
-                   "coef", "fixef", "ranef", "confint", "predict",
-                   "update", "plot", "simulate")
-    for (generic in methods17) {
-        methodname <- paste(generic, "hhh4", sep=".")
-        method <- get(methodname)
-        ## mark ah4-method as deprecated (as of next major release)
-        ## body(method) <- as.call(append(
-        ##     as.list(body(method)),
-        ##     substitute(
-        ##         .Deprecated(new,
-        ##                     msg=c(
-        ##                     "Since surveillance 1.8-0, hhh4()-results are of",
-        ##                     " class \"hhh4\" instead of \"ah4\".",
-        ##                     "\nOld \"ah4\"-methods will be removed.")),
-        ##         list(new=methodname)),
-        ##     after=1L))
-        assign(paste(generic, "ah4", sep="."), method, pos=parent.frame(2L))
-    }
-})
